#
# spec file for package bstone
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2019-2022, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bstone
Version:        1.2.12
Release:        2.4
Summary:        A source port of Blake Stone
# bstone is GPL-2.0+, but statically links GLM (MIT license), STB (public domain or MIT), and xbrz (GPL-3.0+)
License:        GPL-2.0-or-later AND MIT AND GPL-3.0-or-later
Group:          Amusements/Games/3D/Shoot
URL:            https://bibendovsky.github.io/bstone/
Source:         https://github.com/bibendovsky/bstone/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         bstone-fix-build-with-gcc13.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(sdl2)

%description
A source port of the first-person shooter Blake Stone.

Features:
 *  High resolution rendering of world (extended vanilla engine)
 *  Modern and vanilla controls
 *  Allows to customize control bindings
 *  Separate volume control of sound effects and music
Supported games:
 *  Aliens of Gold (v1.0/v2.0/v2.1/v3.0) full or shareware
 *  Planet Strike (v1.0/v1.1)


NOTE: To play Blake Stone with bstone you need the original game files
You need to start the game from within the folder with these files.

%prep
%setup -q
%patch0 -p1

%build
%cmake
%cmake_build

%install
install -Dm0755 build/src/bstone %{buildroot}%{_bindir}/bstone

%files
%license LICENSE "Blake Stone source code license.doc"
%doc CHANGELOG.md README.md
%{_bindir}/bstone

%changelog
* Sun Apr  9 2023 Martin Hauke <mardnh@gmx.de>
- Add patch:
  * bstone-fix-build-with-gcc13.patch
* Sun Sep 18 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.12
  Added
  * Support Nuked OPL3 emulator.
  * Option to control OPL3 emulator type (snd_opl3_type).
  * [README] "Known issues" section.
  Fixed
  * Cancel strafe movement if both keys are pressed.
  * Clear damage effects after loading the game, etc.
  * Fix GOG / Steam content detection.
  * Fix checking if the level is official.
  * Fix crash after changing audio driver via the menu.
  * Match audio attenuation to vanilla as close as possible.
  * Option vid_renderer now works in command-line.
  * Render 3D scene behind "You are jamming" cheat message box.
  * Use SDL 2.0.5+ functions only if available.
  * [AOG] Conditions to complete the episode.
  * [AOG] Fix "N/A" font size and color in the floor input panel.
  * [AOG] Interact with elevator controls on east-west side only.
  * [AOG] Match transporting behavior between floors to original.
  * [AOG] Render ouch frame only on damage for Plasma Sphere.
  * [AOG] Reverse textures for charge packs.
  * [HWR] Render enter-only door size without lock as unlocked.
  * [OAL] List only available extensions.
  * [OAL] Load AL symbols within context.
  * [SDL] Error "Renderer already associated with window".
  * [SDL] Reduce CPU usage for digitized low-pass filtering.
  Changed
  * Limit stream I/O to 32 bit.
  * [OAL] List devices with ALC_ENUMERATE_ALL_EXT if available.
  * [VIDEO] Rename vid_windowed_height to vid_height.
  * [VIDEO] Rename vid_windowed_width to vid_width.
  * [VIDEO] Rename vid_windowed_x to vid_x.
  * [VIDEO] Rename vid_windowed_y to vid_y.
  Removed
  * Exclusive fullscreen mode.
  * Option vid_is_windowed.
  * Resampling low-pass filter and it's options
    (snd_resampling_interpolation, snd_resampling_lpf).
* Sat Jan 29 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Fix license tags (statically linked libraries)
* Sun Mar 21 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.11
  * Bindings to take screenshots (default F5).
  * Option to control weapon bobbing (actual for Planet Strike
    only).
  * PC Speaker SFX.
  * Option snd_sfx_type to switch between AdLib and PC Speaker
    audio.
  * Option snd_is_sfx_digitized to toggle SFX digitization.
  * Extracting unprocessed audio (*.data).
  * Extracting PC Speaker audio.
* Sun Feb 14 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.10
  Added
  * Support for external textures (bmp, png).
  * Configuration for external textures (vid_external_textures).
  * OpenAL 3D audio driver.
  * Configuration for OpenAL driver (snd_driver, snd_oal_library,
    snd_oal_device_name).
  Fixed
  * Search path with provided data_dir.
  * Double fading on new game or load game when using hw renderer.
  * Fade whole screen when in widescreen and 3D view is showing.
  * Next map number for level transition.
  * Support for lowercase resource file names.
* Sat Nov 14 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.9
  Added
  * Option vid_filler_color_index to select filler color.
  Fixed
  * Enable sfx and music by default for first startup.
  * Lives counter.
  * Input floor panel visual glitches.
* Fri Jul 10 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.8
  Fixed
  * Disabled episodes 5 and 6 in static build.
* Tue Jul  7 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.7
  Fixed
  * Extraction of compressed texts.
  * Same texture for door type BIO.
  * Player radius for item pickup.
  * Missing test for pushwall in CheckLine.
  * Fix sfx turning off when in-game sounds paused.
  * Show option "Game Options -> Video -> Stretch UI".
  Changed
  * Replaced almost all fixed-point arithmetic with a
    floating-point one.
  * Relay on CMake's PCH support if available.
* Thu Jun 18 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.6
  Added
  * Option snd_resampling_interpolation to specify interpolation
    method for resampling.
  * Option snd_resampling_lpf to toggle low-pass filter for
    resampling.
* Sat Jun 13 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.5
  Fixed
  * [AOG][E4L1] Removed unnecessary in-place level fix.
- Update to version 1.2.4
  Added
  * [AOG] "Cursor" for elevetor panel.
  * Option --extract_vga_palette to extract VGA palette.
  * Pause game audio when in menu.
  Changed
  * Increased maximum actor count.
  * Use floating point for audio mixing.
  * Rewrite low-pass filter for PCM upsampling.
  * Saved games are not compatible with previous version.
  Fixed
  * [AOG] Revised initial hitpoints for bosses.
  * [AOG][E4L1] Added missing barrier switch for 100%% points.
  * [PS] Hide already pushed pushwall on auto-map.
  * Pickup items while attacking.
  * Sprite precache for Perscan Drone and Volatile Material
    Transport.
  * Both games should be now completable with 100%% rating.
* Wed May 27 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.3
  Added
  * Input bindings to cycle weapons.
  Changed
  * Apply bonus queue after finishing the mission.
  * Write data into temporary file and then rename it.
  * Enable high score menu for debug build.
  * Saved games are not compatible with previous version.
  Fixed
  * [AOG] Animation timings for some actors to match origin.
  * [AOG] Bio-tech placed on special tile (E5L2; (18, 43)).
  * Sprite precache for crate items.
  * Sprite precache for morphed Dr. Goldfire.
  * Level state after death when extra live is available.
  * Add points for destroying projector generator.
  * Displaying pushwalls after loading from saved game.
  * Hit points table.
  * Player's attack tracing.
  * Zigzag movement when strafing along the wall.
  Removed
  * Default values for some input bindings.
* Thu May 14 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.2
  * Fix handling of file paths.
* Wed May 13 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.1
  * Auto-detect game content of GOG and Steam.
  * Show message box with options if multiple game contents found.
* Sat May  9 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.0
  Added
  * 3D-renderer (OpenGL backend).
  * Menu to control video mode.
  * Menu to control texturing.
  * [RHW] Texture upscale filter (xBRZ).
  * Option snd_is_disabled to ignore audio subsystem.
  * Option vid_is_positioned to control position of the window.
  * Option vid_is_widescreen to control widescreen mode.
  * Option vid_is_ui_stretched to control UI stretching.
  * Option vid_2d_texture_filter to control texturing filter for UI
  * Option vid_3d_texture_image_filter to control texturing
    image filter for the scene.
  * Option vid_3d_texture_mipmap_filter to control texturing
    mipmap filter for the scene.
  * Option vid_3d_texture_anisotropy to control anisotropy filter
    for the scene.
  * Option vid_texture_upscale_filter to select texturing upscale
    filter.
  * Option vid_texture_upscale_xbrz_degree to control degree of
    xBRZ filter.
  * Option vid_aa_kind to select anti-aliasing mode.
  * Option vid_aa_degree to select anti-aliasing degree.
  * Option calculate_hashes to calculate hashes of resource files.
  * Option extract_walls to extract graphics resources (wall,
    flooring, etc.).
  * Option extract_sprites to extract graphics resources (actors,
    decorations, etc.).
  * Option extract_music to extract music resources.
  * Option extract_sfx to extract sfx resources.
  * Option extract_texts to extract text resources.
  * Option extract_all to extract all resources.
  * Generic instruction on how to compile on Linux-based system.
  Removed
  * Option vid_scale.
  * Vanilla input bindings and related menu items.
  Changed
  * Renamed option vid_windowed to vid_is_windowed.
  * Renamed option vid_window_x to vid_x.
  * Renamed option vid_window_y to vid_y.
  * Renamed option debug_dump_hashes to calculate_hashes.
  * Split option vid_mode into vid_width and vid_height.
  * Renamed option vid_no_vsync to vid_vsync.
  * Values of option vid_renderer.
  * Serializing barrier switches.
  * Disabled music caching.
  * Reduced volume factor of OPL sounds.
  * Saved games are not compatible with previous versions.
  Fixed
  * Audio normalization.
* Sat Feb  1 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.16
  * Removed some checks on barriers
* Sat Jan 25 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.15
  * Changed: Number secret floor
  * Fixed: Destination position for inter-floor teleporter
* Wed Nov 20 2019 Simon Lees <sflees@suse.de>
- %%make_jobs is depricated replaced by %%cmake_build
* Sat Nov  9 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.14
  * Removed Alt and Ctrl to handle menu item.
  * Fixed Text typos
  * Fixed SDL with two digit sub-version number
  * Apply floor bonus correctly on percentage greater than 100%%
- Remove patch:
  * Fix-SDL2W.patch (fixed by upstream)
* Mon Sep 30 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add Fix-SDL2W.patch to fix the SDL2 detection.
* Sun Jul 14 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.13
  * [AOG] Allow to warp to level beyond the 10th one.
  * Critical error if switch connected to non-activable object.
* Sun Jun 23 2019 Martin Hauke <mardnh@gmx.de>
- Initial package, version 1.1.12
